==> cohesity_management_sdk-1.6.12.tar.gz: cohesity_management_sdk-1.6.12/cohesity_management_sdk/models_v2/vmware_object_type_enum.py <==
# -*- coding: utf-8 -*-

class VmwareObjectTypeEnum(object):

    """Implementation of the 'vmwareObjectType' enum.

    TODO: type enum description here.

    Attributes:
        KVCENTER: TODO: type description here.
        KSTANDALONEHOST: TODO: type description here.
        KVCLOUDDIRECTOR: TODO: type description here.
        KFOLDER: TODO: type description here.
        KDATACENTER: TODO: type description here.
        KCOMPUTERESOURCE: TODO: type description here.
        KCLUSTERCOMPUTERESOURCE: TODO: type description here.
        KRESOURCEPOOL: TODO: type description here.
        KDATASTORE: TODO: type description here.
        KHOSTSYSTEM: TODO: type description here.
        KVIRTUALMACHINE: TODO: type description here.
        KVIRTUALAPP: TODO: type description here.
        KSTORAGEPOD: TODO: type description here.
        KNETWORK: TODO: type description here.
        KDISTRIBUTEDVIRTUALPORTGROUP: TODO: type description here.
        KTAGCATEGORY: TODO: type description here.
        KTAG: TODO: type description here.
        KOPAQUENETWORK: TODO: type description here.
        KORGANIZATION: TODO: type description here.
        KVIRTUALDATACENTER: TODO: type description here.
        KCATALOG: TODO: type description here.
        KORGMETADATA: TODO: type description here.
        KSTORAGEPOLICY: TODO: type description here.
        KVIRTUALAPPTEMPLATE: TODO: type description here.

    """

    KVCENTER = 'kVCenter'

    KSTANDALONEHOST = 'kStandaloneHost'

    K_VCLOUD_DIRECTOR = 'kvCloudDirector'

    KFOLDER = 'kFolder'

    KDATACENTER = 'kDatacenter'

    KCOMPUTERESOURCE = 'kComputeResource'

    KCLUSTERCOMPUTERESOURCE = 'kClusterComputeResource'

    KRESOURCEPOOL = 'kResourcePool'

    KDATASTORE = 'kDatastore'

    KHOSTSYSTEM = 'kHostSystem'

    KVIRTUALMACHINE = 'kVirtualMachine'

    KVIRTUALAPP = 'kVirtualApp'

    KSTORAGEPOD = 'kStoragePod'

    KNETWORK = 'kNetwork'

    KDISTRIBUTEDVIRTUALPORTGROUP = 'kDistributedVirtualPortgroup'

    KTAGCATEGORY = 'kTagCategory'

    KTAG = 'kTag'

    KOPAQUENETWORK = 'kOpaqueNetwork'

    KORGANIZATION = 'kOrganization'

    KVIRTUALDATACENTER = 'kVirtualDatacenter'

    KCATALOG = 'kCatalog'

    KORGMETADATA = 'kOrgMetadata'

    KSTORAGEPOLICY = 'kStoragePolicy'

    KVIRTUALAPPTEMPLATE = 'kVirtualAppTemplate'

==> cohesity_management_sdk-1.6.15.tar.gz: cohesity_management_sdk-1.6.15/cohesity_management_sdk/models_v2/vmware_object_type_enum.py <==
# -*- coding: utf-8 -*-

class VmwareObjectTypeEnum(object):

    """Implementation of the 'vmwareObjectType' enum.

    TODO: type enum description here.

    Attributes:
        KVCENTER: TODO: type description here.
        KSTANDALONEHOST: TODO: type description here.
        K_VCLOUD_DIRECTOR: TODO: type description here.
        KFOLDER: TODO: type description here.
        KDATACENTER: TODO: type description here.
        KCOMPUTERESOURCE: TODO: type description here.
        KCLUSTERCOMPUTERESOURCE: TODO: type description here.
        KRESOURCEPOOL: TODO: type description here.
        KDATASTORE: TODO: type description here.
        KHOSTSYSTEM: TODO: type description here.
        KVIRTUALMACHINE: TODO: type description here.
        KVIRTUALAPP: TODO: type description here.
        KSTORAGEPOD: TODO: type description here.
        KNETWORK: TODO: type description here.
        KDISTRIBUTEDVIRTUALPORTGROUP: TODO: type description here.
        KTAGCATEGORY: TODO: type description here.
        KTAG: TODO: type description here.
        KOPAQUENETWORK: TODO: type description here.
        KORGANIZATION: TODO: type description here.
        KVIRTUALDATACENTER: TODO: type description here.
        KCATALOG: TODO: type description here.
        KORGMETADATA: TODO: type description here.
        KSTORAGEPOLICY: TODO: type description here.
        KVIRTUALAPPTEMPLATE: TODO: type description here.

    """

    KVCENTER = 'kVCenter'

    KSTANDALONEHOST = 'kStandaloneHost'

    K_VCLOUD_DIRECTOR = 'kvCloudDirector'

    KFOLDER = 'kFolder'

    KDATACENTER = 'kDatacenter'

    KCOMPUTERESOURCE = 'kComputeResource'

    KCLUSTERCOMPUTERESOURCE = 'kClusterComputeResource'

    KRESOURCEPOOL = 'kResourcePool'

    KDATASTORE = 'kDatastore'

    KHOSTSYSTEM = 'kHostSystem'

    KVIRTUALMACHINE = 'kVirtualMachine'

    KVIRTUALAPP = 'kVirtualApp'

    KSTORAGEPOD = 'kStoragePod'

    KNETWORK = 'kNetwork'

    KDISTRIBUTEDVIRTUALPORTGROUP = 'kDistributedVirtualPortgroup'

    KTAGCATEGORY = 'kTagCategory'

    KTAG = 'kTag'

    KOPAQUENETWORK = 'kOpaqueNetwork'

    KORGANIZATION = 'kOrganization'

    KVIRTUALDATACENTER = 'kVirtualDatacenter'

    KCATALOG = 'kCatalog'

    KORGMETADATA = 'kOrgMetadata'

    KSTORAGEPOLICY = 'kStoragePolicy'

    KVIRTUALAPPTEMPLATE = 'kVirtualAppTemplate'
